@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs/)
 
 Usage::
 
